@@ -14,7 +14,6 @@
 #include <sys/wait.h>
 #include <sys/socket.h>
 #endif
-#include <fcntl.h>
 #include <errno.h>
 #include <string.h>
 
@@ -234,7 +233,6 @@ static void generic_load(mpg123_handle *fr, char *arg, int state)
 	if(mpg123_meta_check(fr) & MPG123_NEW_ID3)
 	{
 		generic_sendinfoid3(fr);
-		mpg123_meta_free(fr);
 	}
 	else generic_sendinfo(arg);
 
@@ -312,7 +310,7 @@ int control_generic (mpg123_handle *fr)
 #endif
 	/* the command behaviour is different, so is the ID */
 	/* now also with version for command availability */
-	fprintf(outstream, "@R MPG123 (ThOr) v7\n");
+	fprintf(outstream, "@R MPG123 (ThOr) v8\n");
 #ifdef FIFO
 	if(param.fifo)
 	{
@@ -533,6 +531,17 @@ int control_generic (mpg123_handle *fr)
 					continue;
 				}
 
+				if(!strcasecmp(comstr, "FORMAT"))
+				{
+					long rate;
+					int ch;
+					int ret = mpg123_getformat(fr, &rate, &ch, NULL);
+					/* I need to have portable printf specifiers that do not truncate the type... more autoconf... */
+					if(ret < 0) generic_sendmsg("E %s", mpg123_strerror(fr));
+					else generic_sendmsg("FORMAT %li %i", rate, ch);
+					continue;
+				}
+
 				if(!strcasecmp(comstr, "SHOWEQ"))
 				{
 					int i;
@@ -581,11 +590,12 @@ int control_generic (mpg123_handle *fr)
 					generic_sendmsg("H SEEK/K <sample>|<+offset>|<-offset>: jump to output sample position <samples> or change position by offset");
 					generic_sendmsg("H SCAN: scan through the file, building seek index");
 					generic_sendmsg("H SAMPLE: print out the sample position and total number of samples");
+					generic_sendmsg("H FORMAT: print out sampling rate in Hz and channel count");
 					generic_sendmsg("H SEQ <bass> <mid> <treble>: simple eq setting...");
 					generic_sendmsg("H PITCH <[+|-]value>: adjust playback speed (+0.01 is 1 %% faster)");
 					generic_sendmsg("H SILENCE: be silent during playback (meaning silence in text form)");
 					generic_sendmsg("H STATE: Print auxiliary state info in several lines (just try it to see what info is there).");
-					generic_sendmsg("H TAG/T: Print all available (ID3) tag info, for ID3v2 that gives output of all collected text fields, using the ID3v2.3/4 4-character names.");
+					generic_sendmsg("H TAG/T: Print all available (ID3) tag info, for ID3v2 that gives output of all collected text fields, using the ID3v2.3/4 4-character names. NOTE: ID3v2 data will be deleted on non-forward seeks.");
 					generic_sendmsg("H    The output is multiple lines, begin marked by \"@T {\", end by \"@T }\".");
 					generic_sendmsg("H    ID3v1 data is like in the @I info lines (see below), just with \"@T\" in front.");
 					generic_sendmsg("H    An ID3v2 data field is introduced via ([ ... ] means optional):");
@@ -666,6 +676,8 @@ int control_generic (mpg123_handle *fr)
 					if(!strcasecmp(cmd, "K") || !strcasecmp(cmd, "SEEK"))
 					{
 						off_t soff;
+						off_t oldpos;
+						off_t newpos;
 						char *spos = arg;
 						int whence = SEEK_SET;
 						if(mode == MODE_STOPPED)
@@ -673,6 +685,7 @@ int control_generic (mpg123_handle *fr)
 							generic_sendmsg("E No track loaded!");
 							continue;
 						}
+						oldpos = mpg123_tell(fr);
 
 						soff = (off_t) atobigint(spos);
 						if(spos[0] == '-' || spos[0] == '+') whence = SEEK_CUR;
@@ -683,13 +696,17 @@ int control_generic (mpg123_handle *fr)
 						}
 						if(param.usebuffer) buffer_resync();
 
-						generic_sendmsg("K %li", (long)mpg123_tell(fr));
+						newpos = mpg123_tell(fr);
+						if(newpos <= oldpos) mpg123_meta_free(fr);
+
+						generic_sendmsg("K %"OFF_P, (off_p)newpos);
 						continue;
 					}
 					/* JUMP */
 					if (!strcasecmp(cmd, "J") || !strcasecmp(cmd, "JUMP")) {
 						char *spos;
 						off_t offset;
+						off_t oldpos;
 						double secs;
 
 						spos = arg;
@@ -698,6 +715,7 @@ int control_generic (mpg123_handle *fr)
 							generic_sendmsg("E No track loaded!");
 							continue;
 						}
+						oldpos = framenum;
 
 						if(spos[strlen(spos)-1] == 's' && sscanf(arg, "%lf", &secs) == 1) offset = mpg123_timeframe(fr, secs);
 						else offset = atol(spos);
@@ -712,6 +730,7 @@ int control_generic (mpg123_handle *fr)
 						}
 						if(param.usebuffer)	buffer_resync();
 
+						if(framenum <= oldpos) mpg123_meta_free(fr);
 						generic_sendmsg("J %d", framenum);
 						continue;
 					}
